@@ -1,8 +1,6 @@
-from tsdat.config import Config, Keys, QCTestDefinition
+from tsdat.config import Config, Keys, QualityTestDefinition
 from tsdat.io.storage import DatastreamStorage
 from tsdat.io.filesystem_storage import FilesystemStorage
 from tsdat.io.aws_storage import AwsStorage
 from tsdat.pipeline import Pipeline, IngestPipeline
 from tsdat.exceptions import *
-
-
